@@ -29,10 +29,10 @@
 #include "gstlog.h"
 
 static void
-gst_implements_interface_class_init 	   (GstImplementsInterfaceClass *ifklass);
+gst_implements_interface_class_init (GstImplementsInterfaceClass * ifklass);
 static gboolean
-gst_implements_interface_supported_default (GstImplementsInterface *iface,
-					    GType                   iface_type);
+gst_implements_interface_supported_default (GstImplementsInterface * iface,
+    GType iface_type);
 
 GType
 gst_implements_interface_get_type (void)
@@ -54,25 +54,23 @@ gst_implements_interface_get_type (void)
     };
 
     gst_interface_type = g_type_register_static (G_TYPE_INTERFACE,
-						 "GstImplementsInterface",
-						 &gst_interface_info, 0);
+        "GstImplementsInterface", &gst_interface_info, 0);
 
-    g_type_interface_add_prerequisite (gst_interface_type,
-				       GST_TYPE_ELEMENT);
+    g_type_interface_add_prerequisite (gst_interface_type, GST_TYPE_ELEMENT);
   }
 
   return gst_interface_type;
 }
 
 static void
-gst_implements_interface_class_init (GstImplementsInterfaceClass *klass)
+gst_implements_interface_class_init (GstImplementsInterfaceClass * klass)
 {
   klass->supported = gst_implements_interface_supported_default;
 }
 
 static gboolean
-gst_implements_interface_supported_default (GstImplementsInterface *interface,
-					    GType                iface_type)
+gst_implements_interface_supported_default (GstImplementsInterface * interface,
+    GType iface_type)
 {
   /* Well, if someone didn't set the virtual function,
    * then something is clearly wrong. So big no-no here */
@@ -87,19 +85,19 @@ gst_implements_interface_supported_default (GstImplementsInterface *interface,
  *
  * Test whether the given element implements a certain interface of type
  * iface_type, and test whether it is supported for this specific instance.
+ *
+ * Returns: whether or not the element implements the interface.
  */
 
 gboolean
-gst_element_implements_interface (GstElement *element,
-				  GType       iface_type)
+gst_element_implements_interface (GstElement * element, GType iface_type)
 {
-  if (G_TYPE_CHECK_INSTANCE_TYPE (G_OBJECT (element),
-				  iface_type)) {
+  if (G_TYPE_CHECK_INSTANCE_TYPE (G_OBJECT (element), iface_type)) {
     GstImplementsInterface *iface;
     GstImplementsInterfaceClass *ifclass;
 
     iface = G_TYPE_CHECK_INSTANCE_CAST (G_OBJECT (element),
-					iface_type, GstImplementsInterface);
+        iface_type, GstImplementsInterface);
     ifclass = GST_IMPLEMENTS_INTERFACE_GET_CLASS (iface);
 
     if (ifclass->supported != NULL &&
@@ -118,43 +116,44 @@ gst_element_implements_interface (GstElement *element,
  *
  * cast a given object to an interface type, and check whether this
  * interface is supported for this specific instance.
+ *
+ * Returns: a gpointer to the interface type
  */
 
 gpointer
-gst_implements_interface_cast (gpointer from,
-			       GType    iface_type)
+gst_implements_interface_cast (gpointer from, GType iface_type)
 {
   GstImplementsInterface *iface;
 
   /* check cast, give warning+fail if it's invalid */
   if (!(iface = G_TYPE_CHECK_INSTANCE_CAST (from, iface_type,
-					    GstImplementsInterface))) {
+              GstImplementsInterface))) {
     return NULL;
   }
 
   /* if we're an element, take care that this interface
    * is actually implemented */
   if (GST_IS_ELEMENT (from)) {
-    gboolean interface_is_implemented =
-	gst_element_implements_interface (GST_ELEMENT (from), iface_type);
-    g_return_val_if_fail (interface_is_implemented == TRUE, NULL);
+    g_return_val_if_fail (gst_element_implements_interface (GST_ELEMENT (from),
+            iface_type), NULL);
   }
 
   return iface;
 }
 
 /**
- * gst_implements_interface_cast:
+ * gst_implements_interface_check:
  * @from: the object (any sort) from which to check from for the interface
  * @type: the interface type to check for
  *
  * check a given object for an interface implementation, and check
  * whether this interface is supported for this specific instance.
+ *
+ * Returns: whether or not the object implements the given interface
  */
 
 gboolean
-gst_implements_interface_check (gpointer from,
-				GType    type)
+gst_implements_interface_check (gpointer from, GType type)
 {
   GstImplementsInterface *iface;
 
