@@ -1,27 +1,23 @@
 
 #include <gst/gst.h>
 
-int 
+int
 main (int argc, char *argv[])
 {
   GstPlugin *plugin;
   GError *error = NULL;
-  gboolean loaded;
 
   gst_init (&argc, &argv);
 
-  plugin = gst_plugin_new (".libs/libtestplugin.so");
+  plugin = gst_plugin_load_file (".libs/libtestplugin.so", &error);
   g_assert (plugin != NULL);
-
-  loaded = gst_plugin_load_plugin (plugin, &error);
-  if (error)
-  {
+  if (error) {
     g_print ("ERROR loading plug-in: %s\n", error->message);
     g_free (error);
+    return 1;
   }
-  g_assert (loaded == TRUE);
 
-  g_print ("testplugin: %d, %s\n", loaded, plugin->name);
+  g_print ("testplugin: %s\n", gst_plugin_get_name (plugin));
 
   return 0;
 }
