@@ -8,23 +8,21 @@ gboolean mainloop = FALSE;
 static gboolean
 quit_main (gpointer data)
 {
-	if (mainloop)
-	{
-		mainloop = FALSE;
-		g_print ("-");
-		gst_main_quit ();
-	}
-	return TRUE;
+  if (mainloop) {
+    mainloop = FALSE;
+    g_print ("-");
+    gst_main_quit ();
+  }
+  return TRUE;
 }
 
 int
-main (int argc, gchar *argv[])
+main (int argc, gchar * argv[])
 {
   int i;
 
   g_timeout_add (1, quit_main, NULL);
-  for (i = 0; i < 1000; ++i)
-  {
+  for (i = 0; i < 1000; ++i) {
     mainloop = TRUE;
     g_print ("+");
     gst_main ();
