@@ -34,33 +34,33 @@
 #include <locale.h>
 
 static void
-print_caps (const GstCaps *caps, const gchar *pfx)
+print_caps (const GstCaps * caps, const gchar * pfx)
 {
   char *s, *tmp;
   char **v;
 
   s = gst_caps_to_string (caps);
-  
+
   tmp = g_strdup_printf ("\n  %s", pfx);
   v = g_strsplit (s, ", ", -1);
   g_free (s);
   s = g_strjoinv (tmp, v);
   g_strfreev (v);
   g_free (tmp);
-  
+
   tmp = g_strdup_printf ("\n%s", pfx);
   v = g_strsplit (s, "; ", -1);
   g_free (s);
   s = g_strjoinv (tmp, v);
   g_free (tmp);
   g_strfreev (v);
-  
+
   g_print ("%s%s\n", pfx, s);
-  g_free(s);
+  g_free (s);
 }
 
 static void
-print_formats (const GstFormat *formats)
+print_formats (const GstFormat * formats)
 {
   while (formats && *formats) {
     const GstFormatDefinition *definition;
@@ -68,7 +68,7 @@ print_formats (const GstFormat *formats)
     definition = gst_format_get_details (*formats);
     if (definition)
       g_print ("\t\t(%d):\t%s (%s)\n", *formats,
-               definition->nick, definition->description);
+          definition->nick, definition->description);
     else
       g_print ("\t\t(%d):\tUnknown format\n", *formats);
 
@@ -77,7 +77,7 @@ print_formats (const GstFormat *formats)
 }
 
 static void
-print_query_types (const GstQueryType *types)
+print_query_types (const GstQueryType * types)
 {
   while (types && *types) {
     const GstQueryTypeDefinition *definition;
@@ -85,7 +85,7 @@ print_query_types (const GstQueryType *types)
     definition = gst_query_type_get_details (*types);
     if (definition)
       g_print ("\t\t(%d):\t%s (%s)\n", *types,
-               definition->nick, definition->description);
+          definition->nick, definition->description);
     else
       g_print ("\t\t(%d):\tUnknown query format\n", *types);
 
@@ -94,7 +94,7 @@ print_query_types (const GstQueryType *types)
 }
 
 static void
-print_event_masks (const GstEventMask *masks)
+print_event_masks (const GstEventMask * masks)
 {
 #ifndef GST_DISABLE_ENUMTYPES
   GType event_type;
@@ -102,7 +102,7 @@ print_event_masks (const GstEventMask *masks)
   GType event_flags;
   GFlagsClass *flags_class = NULL;
 
-  event_type = gst_event_type_get_type();
+  event_type = gst_event_type_get_type ();
   klass = (GEnumClass *) g_type_class_ref (event_type);
 
   while (masks && masks->type) {
@@ -144,7 +144,7 @@ print_event_masks (const GstEventMask *masks)
 }
 
 static void
-output_hierarchy (GType type, gint level, gint *maxlevel)
+output_hierarchy (GType type, gint level, gint * maxlevel)
 {
   GType parent;
   gint i;
@@ -157,9 +157,9 @@ output_hierarchy (GType type, gint level, gint *maxlevel)
   if (parent)
     output_hierarchy (parent, level, maxlevel);
 
-  for (i=1; i<*maxlevel-level; i++)
-   g_print ("      ");
-  if (*maxlevel-level)
+  for (i = 1; i < *maxlevel - level; i++)
+    g_print ("      ");
+  if (*maxlevel - level)
     g_print (" +----");
 
   g_print ("%s\n", g_type_name (type));
@@ -169,20 +169,21 @@ output_hierarchy (GType type, gint level, gint *maxlevel)
 }
 
 static void
-print_element_properties (GstElement *element)
+print_element_properties (GstElement * element)
 {
   GParamSpec **property_specs;
-  gint num_properties,i;
+  gint num_properties, i;
   gboolean readable;
   const char *string_val;
 
   property_specs = g_object_class_list_properties
-                     (G_OBJECT_GET_CLASS (element), &num_properties);
-  g_print("\nElement Properties:\n");
+      (G_OBJECT_GET_CLASS (element), &num_properties);
+  g_print ("\nElement Properties:\n");
 
   for (i = 0; i < num_properties; i++) {
     GValue value = { 0, };
     GParamSpec *param = property_specs[i];
+
     readable = FALSE;
 
     g_value_init (&value, param->value_type);
@@ -191,8 +192,8 @@ print_element_properties (GstElement *element)
       readable = TRUE;
     }
 
-    g_print("  %-20s: %s\n", g_param_spec_get_name (param),
-                               g_param_spec_get_blurb (param));
+    g_print ("  %-20s: %s\n", g_param_spec_get_name (param),
+        g_param_spec_get_blurb (param));
 
     switch (G_VALUE_TYPE (&value)) {
       case G_TYPE_STRING:
@@ -207,90 +208,105 @@ print_element_properties (GstElement *element)
         break;
       case G_TYPE_BOOLEAN:
         g_print ("%-23.23s Boolean. ", "");
-        if (readable) g_print ("(Default %s)", (g_value_get_boolean (&value) ? "true" : "false"));
+        if (readable)
+          g_print ("(Default %s)",
+              (g_value_get_boolean (&value) ? "true" : "false"));
         break;
       case G_TYPE_ULONG:
       {
         GParamSpecULong *pulong = G_PARAM_SPEC_ULONG (param);
-        g_print("%-23.23s Unsigned Long. ", "");
-        if (readable) g_print("Range: %lu - %lu (Default %lu)",
-                        pulong->minimum, pulong->maximum, g_value_get_ulong (&value));
+
+        g_print ("%-23.23s Unsigned Long. ", "");
+        if (readable)
+          g_print ("Range: %lu - %lu (Default %lu)",
+              pulong->minimum, pulong->maximum, g_value_get_ulong (&value));
         break;
       }
       case G_TYPE_LONG:
       {
         GParamSpecLong *plong = G_PARAM_SPEC_LONG (param);
-        g_print("%-23.23s Long. ", "");
-        if (readable) g_print("Range: %ld - %ld (Default %ld)",
-                        plong->minimum, plong->maximum, g_value_get_long (&value));
+
+        g_print ("%-23.23s Long. ", "");
+        if (readable)
+          g_print ("Range: %ld - %ld (Default %ld)",
+              plong->minimum, plong->maximum, g_value_get_long (&value));
         break;
       }
       case G_TYPE_UINT:
       {
         GParamSpecUInt *puint = G_PARAM_SPEC_UINT (param);
-        g_print("%-23.23s Unsigned Integer. ", "");
-        if (readable) g_print("Range: %u - %u (Default %u)",
-                        puint->minimum, puint->maximum, g_value_get_uint (&value));
+
+        g_print ("%-23.23s Unsigned Integer. ", "");
+        if (readable)
+          g_print ("Range: %u - %u (Default %u)",
+              puint->minimum, puint->maximum, g_value_get_uint (&value));
         break;
       }
       case G_TYPE_INT:
       {
         GParamSpecInt *pint = G_PARAM_SPEC_INT (param);
-        g_print("%-23.23s Integer. ", "");
-        if (readable) g_print("Range: %d - %d (Default %d)",
-                        pint->minimum, pint->maximum, g_value_get_int (&value));
+
+        g_print ("%-23.23s Integer. ", "");
+        if (readable)
+          g_print ("Range: %d - %d (Default %d)",
+              pint->minimum, pint->maximum, g_value_get_int (&value));
         break;
       }
       case G_TYPE_UINT64:
       {
         GParamSpecUInt64 *puint64 = G_PARAM_SPEC_UINT64 (param);
-        g_print("%-23.23s Unsigned Integer64. ", "");
-        if (readable) g_print("Range: %" G_GUINT64_FORMAT " - %"
-                        G_GUINT64_FORMAT " (Default %" G_GUINT64_FORMAT ")",
-                        puint64->minimum, puint64->maximum,
-                        g_value_get_uint64 (&value));
+
+        g_print ("%-23.23s Unsigned Integer64. ", "");
+        if (readable)
+          g_print ("Range: %" G_GUINT64_FORMAT " - %"
+              G_GUINT64_FORMAT " (Default %" G_GUINT64_FORMAT ")",
+              puint64->minimum, puint64->maximum, g_value_get_uint64 (&value));
         break;
       }
       case G_TYPE_INT64:
       {
         GParamSpecInt64 *pint64 = G_PARAM_SPEC_INT64 (param);
-        g_print("%-23.23s Integer64. ", "");
-        if (readable) g_print("Range: %" G_GINT64_FORMAT " - %" G_GINT64_FORMAT                         " (Default %" G_GINT64_FORMAT ")", pint64->minimum,
-                        pint64->maximum, g_value_get_int64 (&value));
+
+        g_print ("%-23.23s Integer64. ", "");
+        if (readable)
+          g_print ("Range: %" G_GINT64_FORMAT " - %" G_GINT64_FORMAT
+              " (Default %" G_GINT64_FORMAT ")", pint64->minimum,
+              pint64->maximum, g_value_get_int64 (&value));
         break;
       }
       case G_TYPE_FLOAT:
       {
         GParamSpecFloat *pfloat = G_PARAM_SPEC_FLOAT (param);
-        g_print("%-23.23s Float. Default: %-8.8s %15.7g\n", "", "",
-                g_value_get_float (&value));
-        g_print("%-23.23s Range: %15.7g - %15.7g", "",
-               pfloat->minimum, pfloat->maximum);
+
+        g_print ("%-23.23s Float. Default: %-8.8s %15.7g\n", "", "",
+            g_value_get_float (&value));
+        g_print ("%-23.23s Range: %15.7g - %15.7g", "",
+            pfloat->minimum, pfloat->maximum);
         break;
       }
       case G_TYPE_DOUBLE:
       {
         GParamSpecDouble *pdouble = G_PARAM_SPEC_DOUBLE (param);
-        g_print("%-23.23s Double. Default: %-8.8s %15.7g\n", "", "",
-                g_value_get_double (&value));
-        g_print("%-23.23s Range: %15.7g - %15.7g", "",
-               pdouble->minimum, pdouble->maximum);
+
+        g_print ("%-23.23s Double. Default: %-8.8s %15.7g\n", "", "",
+            g_value_get_double (&value));
+        g_print ("%-23.23s Range: %15.7g - %15.7g", "",
+            pdouble->minimum, pdouble->maximum);
         break;
       }
       default:
         if (param->value_type == GST_TYPE_URI) {
-          g_print("%-23.23s URI", "");
+          g_print ("%-23.23s URI", "");
         }
         if (param->value_type == GST_TYPE_CAPS) {
           const GstCaps *caps = gst_value_get_caps (&value);
 
           if (!caps)
-            g_print("%-23.23s Caps (NULL)", "");
+            g_print ("%-23.23s Caps (NULL)", "");
           else {
             print_caps (caps, "                           ");
           }
-        }
-        else if (G_IS_PARAM_SPEC_ENUM (param)) {
+        } else if (G_IS_PARAM_SPEC_ENUM (param)) {
           GEnumValue *values;
           guint j = 0;
           gint enum_value;
@@ -301,22 +317,21 @@ print_element_properties (GstElement *element)
           while (values[j].value_name) {
             if (values[j].value == enum_value)
               break;
-            j++; 
+            j++;
           }
 
           g_print ("%-23.23s Enum \"%s\" (default %d, \"%s\")", "",
-                        g_type_name (G_VALUE_TYPE (&value)),
-                        enum_value, values[j].value_nick);
+              g_type_name (G_VALUE_TYPE (&value)),
+              enum_value, values[j].value_nick);
 
           j = 0;
           while (values[j].value_name) {
-            g_print("\n%-23.23s    (%d): \t%s", "",
-                        values[j].value, values[j].value_nick);
+            g_print ("\n%-23.23s    (%d): \t%s", "",
+                values[j].value, values[j].value_nick);
             j++;
           }
           /* g_type_class_unref (ec); */
-        }
-        else if (G_IS_PARAM_SPEC_FLAGS (param)) {
+        } else if (G_IS_PARAM_SPEC_FLAGS (param)) {
           GFlagsValue *values;
           guint j = 0;
           gint flags_value;
@@ -329,35 +344,32 @@ print_element_properties (GstElement *element)
             if (values[j].value & flags_value) {
               if (flags) {
                 g_string_append_printf (flags, " | %s", values[j].value_nick);
-              }
-              else {
+              } else {
                 flags = g_string_new (values[j].value_nick);
               }
             }
             j++;
           }
 
-          g_print("%-23.23s Flags \"%s\" (default %d, \"%s\")", "",
-                      g_type_name (G_VALUE_TYPE (&value)),
-                      flags_value, (flags ? flags->str : "(none)"));
+          g_print ("%-23.23s Flags \"%s\" (default %d, \"%s\")", "",
+              g_type_name (G_VALUE_TYPE (&value)),
+              flags_value, (flags ? flags->str : "(none)"));
 
           j = 0;
           while (values[j].value_name) {
-            g_print("\n%-23.23s    (%d): \t%s", "",
-                      values[j].value, values[j].value_nick);
+            g_print ("\n%-23.23s    (%d): \t%s", "",
+                values[j].value, values[j].value_nick);
             j++;
           }
 
           if (flags)
             g_string_free (flags, TRUE);
-        }
-        else if (G_IS_PARAM_SPEC_OBJECT (param)) {
-          g_print("%-23.23s Object of type \"%s\"", "",
-                      g_type_name(param->value_type));
-        }
-        else {
+        } else if (G_IS_PARAM_SPEC_OBJECT (param)) {
+          g_print ("%-23.23s Object of type \"%s\"", "",
+              g_type_name (param->value_type));
+        } else {
           g_print ("%-23.23s Unknown type %ld \"%s\"", "", param->value_type,
-                      g_type_name(param->value_type));
+              g_type_name (param->value_type));
         }
         break;
     }
@@ -373,7 +385,7 @@ print_element_properties (GstElement *element)
 static char *
 get_rank_name (gint rank)
 {
-  switch(rank){
+  switch (rank) {
     case GST_RANK_NONE:
       return "none";
     case GST_RANK_MARGINAL:
@@ -388,12 +400,11 @@ get_rank_name (gint rank)
 }
 
 static gint
-print_element_info (GstElementFactory *factory)
+print_element_info (GstElementFactory * factory)
 {
   GstElement *element;
   GstObjectClass *gstobject_class;
   GstElementClass *gstelement_class;
-  GList *pads;
   GstPad *pad;
   GstRealPad *realpad;
   GstPadTemplate *padtemplate;
@@ -412,21 +423,24 @@ print_element_info (GstElementFactory *factory)
   gstelement_class = GST_ELEMENT_CLASS (G_OBJECT_GET_CLASS (element));
 
   g_print ("Factory Details:\n");
-  g_print ("  Long name:\t%s\n",   factory->details.longname);
-  g_print ("  Class:\t%s\n",       factory->details.klass);
+  g_print ("  Long name:\t%s\n", factory->details.longname);
+  g_print ("  Class:\t%s\n", factory->details.klass);
   g_print ("  Description:\t%s\n", factory->details.description);
-  g_print ("  Author(s):\t%s\n",   factory->details.author);
-  g_print ("  Rank:\t\t%s\n",      get_rank_name(GST_PLUGIN_FEATURE(factory)->rank));
+  g_print ("  Author(s):\t%s\n", factory->details.author);
+  g_print ("  Rank:\t\t%s\n",
+      get_rank_name (GST_PLUGIN_FEATURE (factory)->rank));
   g_print ("\n");
 
   output_hierarchy (G_OBJECT_TYPE (element), 0, &maxlevel);
 
   g_print ("Pad Templates:\n");
   if (factory->numpadtemplates) {
+    const GList *pads;
+
     pads = factory->padtemplates;
     while (pads) {
-      padtemplate = (GstPadTemplate*)(pads->data);
-      pads = g_list_next(pads);
+      padtemplate = (GstPadTemplate *) (pads->data);
+      pads = g_list_next (pads);
 
       if (padtemplate->direction == GST_PAD_SRC)
         g_print ("  SRC template: '%s'\n", padtemplate->name_template);
@@ -442,9 +456,8 @@ print_element_info (GstElementFactory *factory)
       else if (padtemplate->presence == GST_PAD_REQUEST) {
         g_print ("    Availability: On request\n");
         g_print ("      Has request_new_pad() function: %s\n",
-                GST_DEBUG_FUNCPTR_NAME (gstelement_class->request_new_pad));
-      }
-      else
+            GST_DEBUG_FUNCPTR_NAME (gstelement_class->request_new_pad));
+      } else
         g_print ("    Availability: UNKNOWN!!!\n");
 
       if (padtemplate->caps) {
@@ -473,11 +486,11 @@ print_element_info (GstElementFactory *factory)
     have_flags = TRUE;
   }
   if (GST_FLAG_IS_SET (element, GST_ELEMENT_EVENT_AWARE)) {
-    g_print("  GST_ELEMENT_EVENT_AWARE\n");
+    g_print ("  GST_ELEMENT_EVENT_AWARE\n");
     have_flags = TRUE;
   }
   if (!have_flags)
-    g_print("  no flags set\n");
+    g_print ("  no flags set\n");
 
   if (GST_IS_BIN (element)) {
     g_print ("\nBin Flags:\n");
@@ -503,17 +516,17 @@ print_element_info (GstElementFactory *factory)
 
   if (element->loopfunc)
     g_print ("  loopfunc()-based element: %s\n",
-            GST_DEBUG_FUNCPTR_NAME (element->loopfunc));
+        GST_DEBUG_FUNCPTR_NAME (element->loopfunc));
   else
     g_print ("  No loopfunc(), must be chain-based or not configured yet\n");
 
   g_print ("  Has change_state() function: %s\n",
-          GST_DEBUG_FUNCPTR_NAME (gstelement_class->change_state));
+      GST_DEBUG_FUNCPTR_NAME (gstelement_class->change_state));
 #ifndef GST_DISABLE_LOADSAVE
   g_print ("  Has custom save_thyself() function: %s\n",
-          GST_DEBUG_FUNCPTR_NAME (gstobject_class->save_thyself));
+      GST_DEBUG_FUNCPTR_NAME (gstobject_class->save_thyself));
   g_print ("  Has custom restore_thyself() function: %s\n",
-          GST_DEBUG_FUNCPTR_NAME (gstobject_class->restore_thyself));
+      GST_DEBUG_FUNCPTR_NAME (gstobject_class->restore_thyself));
 #endif
 
   have_flags = FALSE;
@@ -528,7 +541,7 @@ print_element_info (GstElementFactory *factory)
 
     clock = gst_element_get_clock (element);
     if (clock)
-      g_print ("  element provides a clock: %s\n", GST_OBJECT_NAME(clock));
+      g_print ("  element provides a clock: %s\n", GST_OBJECT_NAME (clock));
     else
       g_print ("  element is supposed to provide a clock but returned NULL\n");
     have_flags = TRUE;
@@ -536,13 +549,11 @@ print_element_info (GstElementFactory *factory)
   if (!have_flags) {
     g_print ("  none\n");
   }
-
 #ifndef GST_DISABLE_INDEX
   g_print ("\nIndexing capabilities:\n");
   if (gst_element_is_indexable (element)) {
     g_print ("  element can do indexing\n");
-  }
-  else {
+  } else {
     g_print ("  none\n");
   }
 #endif
@@ -550,6 +561,7 @@ print_element_info (GstElementFactory *factory)
   g_print ("\nPads:\n");
   if (element->numpads) {
     const GList *pads;
+
     pads = gst_element_get_pad_list (element);
     while (pads) {
       pad = GST_PAD (pads->data);
@@ -571,27 +583,27 @@ print_element_info (GstElementFactory *factory)
       g_print ("    Implementation:\n");
       if (realpad->chainfunc)
         g_print ("      Has chainfunc(): %s\n",
-                GST_DEBUG_FUNCPTR_NAME (realpad->chainfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->chainfunc));
       if (realpad->getfunc)
         g_print ("      Has getfunc(): %s\n",
-                GST_DEBUG_FUNCPTR_NAME (realpad->getfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->getfunc));
       if (realpad->formatsfunc != gst_pad_get_formats_default) {
         g_print ("      Supports seeking/conversion/query formats:\n");
         print_formats (gst_pad_get_formats (GST_PAD (realpad)));
       }
       if (realpad->convertfunc != gst_pad_convert_default)
         g_print ("      Has custom convertfunc(): %s\n",
-                GST_DEBUG_FUNCPTR_NAME (realpad->convertfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->convertfunc));
       if (realpad->eventfunc != gst_pad_event_default)
         g_print ("      Has custom eventfunc(): %s\n",
-                GST_DEBUG_FUNCPTR_NAME (realpad->eventfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->eventfunc));
       if (realpad->eventmaskfunc != gst_pad_get_event_masks_default) {
         g_print ("        Provides event masks:\n");
         print_event_masks (gst_pad_get_event_masks (GST_PAD (realpad)));
       }
       if (realpad->queryfunc != gst_pad_query_default)
         g_print ("      Has custom queryfunc(): %s\n",
-                GST_DEBUG_FUNCPTR_NAME (realpad->queryfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->queryfunc));
       if (realpad->querytypefunc != gst_pad_get_query_types_default) {
         g_print ("        Provides query types:\n");
         print_query_types (gst_pad_get_query_types (GST_PAD (realpad)));
@@ -599,15 +611,14 @@ print_element_info (GstElementFactory *factory)
 
       if (realpad->intlinkfunc != gst_pad_get_internal_links_default)
         g_print ("      Has custom intconnfunc(): %s\n",
-                GST_DEBUG_FUNCPTR_NAME(realpad->intlinkfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->intlinkfunc));
 
       if (realpad->bufferallocfunc)
         g_print ("      Has bufferallocfunc(): %s\n",
-                GST_DEBUG_FUNCPTR_NAME(realpad->bufferallocfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->bufferallocfunc));
 
       if (pad->padtemplate)
-        g_print ("    Pad Template: '%s'\n",
-                pad->padtemplate->name_template);
+        g_print ("    Pad Template: '%s'\n", pad->padtemplate->name_template);
 
       if (realpad->caps) {
         g_print ("    Capabilities:\n");
@@ -621,12 +632,12 @@ print_element_info (GstElementFactory *factory)
 
   /* Dynamic Parameters block */
   {
-    GstDParamManager* dpman;
-    GParamSpec** specs;
+    GstDParamManager *dpman;
+    GParamSpec **specs;
     gint x;
 
     g_print ("\nDynamic Parameters:\n");
-    if((dpman = gst_dpman_get_manager (element))) {
+    if ((dpman = gst_dpman_get_manager (element))) {
       specs = gst_dpman_list_dparam_specs (dpman);
       for (x = 0; specs[x] != NULL; x++) {
         g_print ("  %-20.20s: ", g_param_spec_get_name (specs[x]));
@@ -634,38 +645,38 @@ print_element_info (GstElementFactory *factory)
         switch (G_PARAM_SPEC_VALUE_TYPE (specs[x])) {
           case G_TYPE_INT64:
             g_print ("64 Bit Integer (Default %" G_GINT64_FORMAT ", Range %"
-                         G_GINT64_FORMAT " -> %" G_GINT64_FORMAT ")",
-            ((GParamSpecInt64 *) specs[x])->default_value,
-            ((GParamSpecInt64 *) specs[x])->minimum,
-            ((GParamSpecInt64 *) specs[x])->maximum);
+                G_GINT64_FORMAT " -> %" G_GINT64_FORMAT ")",
+                ((GParamSpecInt64 *) specs[x])->default_value,
+                ((GParamSpecInt64 *) specs[x])->minimum,
+                ((GParamSpecInt64 *) specs[x])->maximum);
             break;
           case G_TYPE_INT:
             g_print ("Integer (Default %d, Range %d -> %d)",
-            ((GParamSpecInt *) specs[x])->default_value,
-            ((GParamSpecInt *) specs[x])->minimum,
-            ((GParamSpecInt *) specs[x])->maximum);
+                ((GParamSpecInt *) specs[x])->default_value,
+                ((GParamSpecInt *) specs[x])->minimum,
+                ((GParamSpecInt *) specs[x])->maximum);
             break;
           case G_TYPE_FLOAT:
             g_print ("Float. Default: %-8.8s %15.7g\n", "",
-              ((GParamSpecFloat *) specs[x])->default_value);
+                ((GParamSpecFloat *) specs[x])->default_value);
             g_print ("%-23.23s Range: %15.7g - %15.7g", "",
-              ((GParamSpecFloat *) specs[x])->minimum,
-              ((GParamSpecFloat *) specs[x])->maximum);
+                ((GParamSpecFloat *) specs[x])->minimum,
+                ((GParamSpecFloat *) specs[x])->maximum);
             break;
           case G_TYPE_DOUBLE:
             g_print ("Double. Default: %-8.8s %15.7g\n", "",
-              ((GParamSpecDouble *) specs[x])->default_value);
+                ((GParamSpecDouble *) specs[x])->default_value);
             g_print ("%-23.23s Range: %15.7g - %15.7g", "",
-              ((GParamSpecDouble *) specs[x])->minimum,
-              ((GParamSpecDouble *) specs[x])->maximum);
+                ((GParamSpecDouble *) specs[x])->minimum,
+                ((GParamSpecDouble *) specs[x])->maximum);
             break;
-        default: g_print ("unknown %ld", G_PARAM_SPEC_VALUE_TYPE (specs[x]));
+          default:
+            g_print ("unknown %ld", G_PARAM_SPEC_VALUE_TYPE (specs[x]));
         }
         g_print ("\n");
       }
       g_free (specs);
-    }
-    else {
+    } else {
       g_print ("  none\n");
     }
   }
@@ -686,43 +697,45 @@ print_element_info (GstElementFactory *factory)
       else
         g_print ("\nElement Actions:\n");
 
-      for(type = G_OBJECT_TYPE(element); type; type = g_type_parent(type)){
+      for (type = G_OBJECT_TYPE (element); type; type = g_type_parent (type)) {
         signals = g_signal_list_ids (type, &nsignals);
 
-	for (i = 0; i < nsignals; i++) {
-	  gint n_params;
-	  GType return_type;
-	  const GType *param_types;
-	  gint j;
+        for (i = 0; i < nsignals; i++) {
+          gint n_params;
+          GType return_type;
+          const GType *param_types;
+          gint j;
 
-	  query = g_new0 (GSignalQuery,1);
-	  g_signal_query (signals[i], query);
+          query = g_new0 (GSignalQuery, 1);
+          g_signal_query (signals[i], query);
 
-	  if ((k == 0 && !(query->signal_flags & G_SIGNAL_ACTION)) ||
-	      (k == 1 &&  (query->signal_flags & G_SIGNAL_ACTION))) {
-	    n_params = query->n_params;
-	    return_type = query->return_type;
-	    param_types = query->param_types;
+          if ((k == 0 && !(query->signal_flags & G_SIGNAL_ACTION)) ||
+              (k == 1 && (query->signal_flags & G_SIGNAL_ACTION))) {
+            n_params = query->n_params;
+            return_type = query->return_type;
+            param_types = query->param_types;
 
-	    g_print ("  \"%s\" :\t %s user_function (%s* object",
-		    query->signal_name, g_type_name (return_type),
-		    g_type_name (type));
+            g_print ("  \"%s\" :\t %s user_function (%s* object",
+                query->signal_name, g_type_name (return_type),
+                g_type_name (type));
 
-	    for (j = 0; j < n_params; j++) {
-	      g_print (",\n    \t\t\t\t%s arg%d", g_type_name(param_types[j]), j);
-	    }
-	    if (k == 0)
-	      g_print (",\n    \t\t\t\tgpointer user_data);\n");
-	    else
-	      g_print (");\n");
+            for (j = 0; j < n_params; j++) {
+              g_print (",\n    \t\t\t\t%s arg%d", g_type_name (param_types[j]),
+                  j);
+            }
+            if (k == 0)
+              g_print (",\n    \t\t\t\tgpointer user_data);\n");
+            else
+              g_print (");\n");
 
-	    counted++;
-	  }
+            counted++;
+          }
 
-	  g_free (query);
-	}
+          g_free (query);
+        }
       }
-      if (counted == 0) g_print ("  none\n");
+      if (counted == 0)
+        g_print ("  none\n");
     }
   }
 
@@ -750,12 +763,12 @@ print_element_list (void)
 {
   GList *plugins;
 
-  plugins = gst_registry_pool_plugin_list();
+  plugins = gst_registry_pool_plugin_list ();
   while (plugins) {
     GList *features;
     GstPlugin *plugin;
 
-    plugin = (GstPlugin*)(plugins->data);
+    plugin = (GstPlugin *) (plugins->data);
     plugins = g_list_next (plugins);
 
     features = gst_plugin_get_feature_list (plugin);
@@ -769,7 +782,7 @@ print_element_list (void)
 
         factory = GST_ELEMENT_FACTORY (feature);
         g_print ("%s:  %s: %s\n", plugin->desc.name,
-                GST_PLUGIN_FEATURE_NAME (factory) ,factory->details.longname);
+            GST_PLUGIN_FEATURE_NAME (factory), factory->details.longname);
       }
 #ifndef GST_DISABLE_INDEX
       else if (GST_IS_INDEX_FACTORY (feature)) {
@@ -777,36 +790,36 @@ print_element_list (void)
 
         factory = GST_INDEX_FACTORY (feature);
         g_print ("%s:  %s: %s\n", plugin->desc.name,
-                GST_PLUGIN_FEATURE_NAME (factory), factory->longdesc);
+            GST_PLUGIN_FEATURE_NAME (factory), factory->longdesc);
       }
 #endif
       else if (GST_IS_TYPE_FIND_FACTORY (feature)) {
         GstTypeFindFactory *factory;
 
         factory = GST_TYPE_FIND_FACTORY (feature);
-        g_print ("%s: %s: ", plugin->desc.name, gst_plugin_feature_get_name (feature));
+        g_print ("%s: %s: ", plugin->desc.name,
+            gst_plugin_feature_get_name (feature));
         if (factory->extensions) {
-	  guint i = 0;
-	  while (factory->extensions[i]) {
-	    g_print ("%s%s", i > 0 ? ", " : "", factory->extensions[i]);
-	    i++;
-	  }
+          guint i = 0;
+
+          while (factory->extensions[i]) {
+            g_print ("%s%s", i > 0 ? ", " : "", factory->extensions[i]);
+            i++;
+          }
           g_print ("\n");
-	} else {
+        } else {
           g_print ("no extensions\n");
         }
-      }
-      else if (GST_IS_SCHEDULER_FACTORY (feature)) {
+      } else if (GST_IS_SCHEDULER_FACTORY (feature)) {
         GstSchedulerFactory *factory;
 
         factory = GST_SCHEDULER_FACTORY (feature);
         g_print ("%s:  %s: %s\n", plugin->desc.name,
-                GST_PLUGIN_FEATURE_NAME (factory), factory->longdesc);
-      }
-      else {
+            GST_PLUGIN_FEATURE_NAME (factory), factory->longdesc);
+      } else {
         g_print ("%s:  %s (%s)\n", plugin->desc.name,
-                GST_PLUGIN_FEATURE_NAME (feature),
-                g_type_name (G_OBJECT_TYPE (feature)));
+            GST_PLUGIN_FEATURE_NAME (feature),
+            g_type_name (G_OBJECT_TYPE (feature)));
       }
 
       features = g_list_next (features);
@@ -815,7 +828,7 @@ print_element_list (void)
 }
 
 static void
-print_plugin_info (GstPlugin *plugin)
+print_plugin_info (GstPlugin * plugin)
 {
   GList *features;
   gint num_features = 0;
@@ -826,13 +839,13 @@ print_plugin_info (GstPlugin *plugin)
   gint num_other = 0;
 
   g_print ("Plugin Details:\n");
-  g_print ("  Name:\t\t%s\n",	    plugin->desc.name);
-  g_print ("  Description:\t%s\n",  plugin->desc.description);
-  g_print ("  Filename:\t%s\n",	    plugin->filename);
-  g_print ("  Version:\t%s\n",	    plugin->desc.version);
-  g_print ("  License:\t%s\n",	    plugin->desc.license);
-  g_print ("  Package:\t%s\n",	    plugin->desc.package);
-  g_print ("  Origin URL:\t%s\n",   plugin->desc.origin);
+  g_print ("  Name:\t\t%s\n", plugin->desc.name);
+  g_print ("  Description:\t%s\n", plugin->desc.description);
+  g_print ("  Filename:\t%s\n", plugin->filename);
+  g_print ("  Version:\t%s\n", plugin->desc.version);
+  g_print ("  License:\t%s\n", plugin->desc.license);
+  g_print ("  Package:\t%s\n", plugin->desc.package);
+  g_print ("  Origin URL:\t%s\n", plugin->desc.origin);
   g_print ("\n");
 
   features = gst_plugin_get_feature_list (plugin);
@@ -847,7 +860,7 @@ print_plugin_info (GstPlugin *plugin)
 
       factory = GST_ELEMENT_FACTORY (feature);
       g_print ("  %s: %s\n", GST_OBJECT_NAME (factory),
-              factory->details.longname);
+          factory->details.longname);
       num_elements++;
     }
 #ifndef GST_DISABLE_INDEX
@@ -864,27 +877,26 @@ print_plugin_info (GstPlugin *plugin)
 
       factory = GST_TYPE_FIND_FACTORY (feature);
       if (factory->extensions) {
-	guint i = 0;
-	g_print ("%s type: ", plugin->desc.name);
-	while (factory->extensions[i]) {
-	  g_print ("%s%s", i > 0 ? ", " : "", factory->extensions[i]);
-	  i++;
-	}
+        guint i = 0;
+
+        g_print ("%s type: ", plugin->desc.name);
+        while (factory->extensions[i]) {
+          g_print ("%s%s", i > 0 ? ", " : "", factory->extensions[i]);
+          i++;
+        }
       } else
-	g_print ("%s type: N/A\n", plugin->desc.name);
+        g_print ("%s type: N/A\n", plugin->desc.name);
 
       num_types++;
-    }
-    else if (GST_IS_SCHEDULER_FACTORY (feature)) {
+    } else if (GST_IS_SCHEDULER_FACTORY (feature)) {
       GstSchedulerFactory *factory;
 
       factory = GST_SCHEDULER_FACTORY (feature);
       g_print ("  %s: %s\n", GST_OBJECT_NAME (factory), factory->longdesc);
       num_schedulers++;
-    }
-    else {
+    } else {
       g_print ("  %s (%s)\n", gst_object_get_name (GST_OBJECT (feature)),
-                             g_type_name (G_OBJECT_TYPE (feature)));
+          g_type_name (G_OBJECT_TYPE (feature)));
       num_other++;
     }
     num_features++;
@@ -912,15 +924,16 @@ main (int argc, char *argv[])
   GstPlugin *plugin;
   gchar *so;
   struct poptOption options[] = {
-    {"gst-inspect-plugin", 'p', POPT_ARG_STRING|POPT_ARGFLAG_STRIP, NULL, 0,
-                   N_("Show plugin details"), NULL},
-    {"gst-inspect-scheduler", 's', POPT_ARG_STRING|POPT_ARGFLAG_STRIP, NULL, 0,
-                   N_("Show scheduler details"), NULL},
+    {"gst-inspect-plugin", 'p', POPT_ARG_STRING | POPT_ARGFLAG_STRIP, NULL, 0,
+        N_("Show plugin details"), NULL},
+    {"gst-inspect-scheduler", 's', POPT_ARG_STRING | POPT_ARGFLAG_STRIP, NULL,
+          0,
+        N_("Show scheduler details"), NULL},
     POPT_TABLEEND
   };
 
-  setlocale (LC_ALL, "");
   bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
   gst_init_with_popt_table (&argc, &argv, options);
@@ -928,62 +941,62 @@ main (int argc, char *argv[])
 
   /* if no arguments, print out list of elements */
   if (argc == 1) {
-    print_element_list();
+    print_element_list ();
 
-  /* else we try to get a factory */
+    /* else we try to get a factory */
   } else {
     /* first check for help */
     if (strstr (argv[1], "-help")) {
-      g_print ("Usage: %s\t\t\tList all registered elements\n",argv[0]);
-      g_print ("       %s element-name\tShow element details\n",argv[0]);
+      g_print ("Usage: %s\t\t\tList all registered elements\n", argv[0]);
+      g_print ("       %s element-name\tShow element details\n", argv[0]);
       g_print ("       %s plugin-name[.so]\tShow information about plugin\n",
-              argv[0]);
+          argv[0]);
       return 0;
     }
 
     /* only search for a factory if there's not a '.so' */
-    if (! strstr (argv[1], ".so")) {
+    if (!strstr (argv[1], ".so")) {
       factory = gst_element_factory_find (argv[1]);
 
       /* if there's a factory, print out the info */
       if (factory)
         return print_element_info (factory);
       else {
-         GstPluginFeature* feature;
+        GstPluginFeature *feature;
 
-         /* FIXME implement other pretty print function for these */
-         feature = gst_registry_pool_find_feature (argv[1],
-                                                   GST_TYPE_SCHEDULER_FACTORY);
-         if (feature) {
-           g_print ("%s: a scheduler\n", argv[1]);
-           return 0;
-         }
+        /* FIXME implement other pretty print function for these */
+        feature = gst_registry_pool_find_feature (argv[1],
+            GST_TYPE_SCHEDULER_FACTORY);
+        if (feature) {
+          g_print ("%s: a scheduler\n", argv[1]);
+          return 0;
+        }
 #ifndef GST_DISABLE_INDEX
-         feature = gst_registry_pool_find_feature (argv[1],
-                                                   GST_TYPE_INDEX_FACTORY);
-         if (feature) {
-           g_print ("%s: an index\n", argv[1]);
-           return 0;
-         }
+        feature = gst_registry_pool_find_feature (argv[1],
+            GST_TYPE_INDEX_FACTORY);
+        if (feature) {
+          g_print ("%s: an index\n", argv[1]);
+          return 0;
+        }
 #endif
-         feature = gst_registry_pool_find_feature (argv[1],
-                                                   GST_TYPE_TYPE_FIND_FACTORY);
-         if (feature) {
-           g_print ("%s: a typefind function\n", argv[1]);
-           return 0;
-         }
+        feature = gst_registry_pool_find_feature (argv[1],
+            GST_TYPE_TYPE_FIND_FACTORY);
+        if (feature) {
+          g_print ("%s: a typefind function\n", argv[1]);
+          return 0;
+        }
 #ifndef GST_DISABLE_URI
-         feature = gst_registry_pool_find_feature (argv[1],
-                                                   GST_TYPE_URI_HANDLER);
-         if (feature) {
-           g_print ("%s: an uri handler\n", argv[1]);
-           return 0;
-         }
+        feature = gst_registry_pool_find_feature (argv[1],
+            GST_TYPE_URI_HANDLER);
+        if (feature) {
+          g_print ("%s: an uri handler\n", argv[1]);
+          return 0;
+        }
 #endif
       }
     } else {
       /* strip the .so */
-      so = strstr(argv[1],".so");
+      so = strstr (argv[1], ".so");
       so[0] = '\0';
     }
 
@@ -996,7 +1009,7 @@ main (int argc, char *argv[])
       print_plugin_info (plugin);
 
     } else {
-      g_print("no such element or plugin '%s'\n", argv[1]);
+      g_print ("no such element or plugin '%s'\n", argv[1]);
       return -1;
     }
   }
