@@ -30,7 +30,7 @@
 #include <signal.h>
 #include <unistd.h>
 #include <sys/wait.h>
-#include <locale.h> /* for LC_ALL */
+#include <locale.h>             /* for LC_ALL */
 #include "gst/gst-i18n-app.h"
 
 #include <gst/gst.h>
@@ -67,25 +67,27 @@ idle_func (gpointer data)
   iterations++;
   g_get_current_time (&tfnow);
 
-  diff = GST_TIMEVAL_TO_TIME (tfnow) -
-         GST_TIMEVAL_TO_TIME (tfthen);
+  diff = GST_TIMEVAL_TO_TIME (tfnow) - GST_TIMEVAL_TO_TIME (tfthen);
 
-  sum += diff; 
+  sum += diff;
   min = MIN (min, diff);
   max = MAX (max, diff);
 
-  if (!busy || caught_intr || (max_iterations>0 && iterations>=max_iterations)) {
+  if (!busy || caught_intr || (max_iterations > 0
+          && iterations >= max_iterations)) {
     gst_main_quit ();
-    g_print (_("Execution ended after %" G_GUINT64_FORMAT " iterations (sum %" G_GUINT64_FORMAT " ns, average %" G_GUINT64_FORMAT " ns, min %" G_GUINT64_FORMAT " ns, max %" G_GUINT64_FORMAT " ns).\n"),
-		    iterations, sum, sum/iterations, min, max);
+    g_print (_("Execution ended after %" G_GUINT64_FORMAT " iterations (sum %"
+            G_GUINT64_FORMAT " ns, average %" G_GUINT64_FORMAT " ns, min %"
+            G_GUINT64_FORMAT " ns, max %" G_GUINT64_FORMAT " ns).\n"),
+        iterations, sum, sum / iterations, min, max);
   }
 
   return busy;
 }
 
 #ifndef GST_DISABLE_LOADSAVE
-static GstElement*
-xmllaunch_parse_cmdline (const gchar **argv)
+static GstElement *
+xmllaunch_parse_cmdline (const gchar ** argv)
 {
   GstElement *pipeline = NULL, *e;
   GstXML *xml;
@@ -94,45 +96,50 @@ xmllaunch_parse_cmdline (const gchar **argv)
   gchar *element, *property, *value;
   GList *l;
   gint i = 0;
-  
+
   if (!(arg = argv[0])) {
-    g_print (_("Usage: gst-xmllaunch <file.xml> [ element.property=value ... ]\n"));
+    g_print (_
+        ("Usage: gst-xmllaunch <file.xml> [ element.property=value ... ]\n"));
     exit (1);
   }
-  
+
   xml = gst_xml_new ();
-  err = gst_xml_parse_file(xml, arg, NULL);
-  
+  err = gst_xml_parse_file (xml, arg, NULL);
+
   if (err != TRUE) {
     fprintf (stderr, _("ERROR: parse of xml file '%s' failed.\n"), arg);
     exit (1);
   }
-  
+
   l = gst_xml_get_topelements (xml);
   if (!l) {
-    fprintf (stderr, _("ERROR: no toplevel pipeline element in file '%s'.\n"), arg);
+    fprintf (stderr, _("ERROR: no toplevel pipeline element in file '%s'.\n"),
+        arg);
     exit (1);
   }
-    
+
   if (l->next)
-    fprintf (stderr,  _("WARNING: only one toplevel element is supported at this time."));
-  
+    fprintf (stderr,
+        _("WARNING: only one toplevel element is supported at this time."));
+
   pipeline = GST_ELEMENT (l->data);
-  
+
   while ((arg = argv[++i])) {
     element = g_strdup (arg);
     property = strchr (element, '.');
     value = strchr (element, '=');
-    
+
     if (!(element < property && property < value)) {
-      fprintf (stderr, _("ERROR: could not parse command line argument %d: %s.\n"), i, element);
+      fprintf (stderr,
+          _("ERROR: could not parse command line argument %d: %s.\n"), i,
+          element);
       g_free (element);
       exit (1);
     }
-    
+
     *property++ = '\0';
     *value++ = '\0';
-    
+
     e = gst_bin_get_by_name (GST_BIN (pipeline), element);
     if (!e) {
       fprintf (stderr, _("WARNING: element named '%s' not found.\n"), element);
@@ -141,7 +148,7 @@ xmllaunch_parse_cmdline (const gchar **argv)
     }
     g_free (element);
   }
-  
+
   if (!l)
     return NULL;
   else
@@ -150,7 +157,7 @@ xmllaunch_parse_cmdline (const gchar **argv)
 #endif
 
 #ifndef USE_SIGINFO
-static void 
+static void
 fault_handler_sighandler (int signum)
 {
   fault_restore ();
@@ -167,13 +174,13 @@ fault_handler_sighandler (int signum)
       break;
   }
 
-  fault_spin();
+  fault_spin ();
 }
 
 #else
 
-static void 
-fault_handler_sigaction (int signum, siginfo_t *si, void *misc)
+static void
+fault_handler_sigaction (int signum, siginfo_t * si, void *misc)
 {
   fault_restore ();
 
@@ -191,7 +198,7 @@ fault_handler_sigaction (int signum, siginfo_t *si, void *misc)
       break;
   }
 
-  fault_spin();
+  fault_spin ();
 }
 #endif
 
@@ -207,12 +214,12 @@ fault_spin (void)
 
   /* FIXME how do we know if we were run by libtool? */
   g_print ("Spinning.  Please run 'gdb gst-launch %d' to continue debugging, "
-  	   "Ctrl-C to quit, or Ctrl-\\ to dump core.\n",
-  	   (gint) getpid ());
-  while (spinning) g_usleep (1000000);
+      "Ctrl-C to quit, or Ctrl-\\ to dump core.\n", (gint) getpid ());
+  while (spinning)
+    g_usleep (1000000);
 }
 
-static void 
+static void
 fault_restore (void)
 {
   struct sigaction action;
@@ -224,7 +231,7 @@ fault_restore (void)
   sigaction (SIGQUIT, &action, NULL);
 }
 
-static void 
+static void
 fault_setup (void)
 {
   struct sigaction action;
@@ -242,7 +249,7 @@ fault_setup (void)
 }
 
 static void
-print_tag (const GstTagList *list, const gchar *tag, gpointer unused)
+print_tag (const GstTagList * list, const gchar * tag, gpointer unused)
 {
   gint i, count;
 
@@ -250,14 +257,14 @@ print_tag (const GstTagList *list, const gchar *tag, gpointer unused)
 
   for (i = 0; i < count; i++) {
     gchar *str;
-    
+
     if (gst_tag_get_type (tag) == G_TYPE_STRING) {
       g_assert (gst_tag_list_get_string_index (list, tag, i, &str));
     } else {
-      str = g_strdup_value_contents (
-	      gst_tag_list_get_value_index (list, tag, i));
+      str =
+          g_strdup_value_contents (gst_tag_list_get_value_index (list, tag, i));
     }
-  
+
     if (i == 0) {
       g_print ("%15s: %s\n", gst_tag_get_nick (tag), str);
     } else {
@@ -268,10 +275,10 @@ print_tag (const GstTagList *list, const gchar *tag, gpointer unused)
   }
 }
 static void
-found_tag (GObject *pipeline, GstElement *source, GstTagList *tags)
+found_tag (GObject * pipeline, GstElement * source, GstTagList * tags)
 {
   g_print (_("FOUND TAG      : found by element \"%s\".\n"),
-           GST_STR_NULL (GST_ELEMENT_NAME (source)));
+      GST_STR_NULL (GST_ELEMENT_NAME (source)));
   gst_tag_list_foreach (tags, print_tag, NULL);
 }
 
@@ -281,7 +288,7 @@ sigint_handler_sighandler (int signum)
 {
   g_print ("Caught interrupt.\n");
 
-  sigint_restore();
+  sigint_restore ();
 
   caught_intr = TRUE;
 }
@@ -297,7 +304,7 @@ sigint_setup (void)
   sigaction (SIGINT, &action, NULL);
 }
 
-static void 
+static void
 sigint_restore (void)
 {
   struct sigaction action;
@@ -324,7 +331,7 @@ play_handler (int signum)
 }
 
 static void
-play_signal_setup(void)
+play_signal_setup (void)
 {
   struct sigaction action;
 
@@ -335,9 +342,10 @@ play_signal_setup(void)
 }
 
 int
-main(int argc, char *argv[])
+main (int argc, char *argv[])
 {
   gint i, j;
+
   /* options */
   gboolean verbose = FALSE;
   gboolean tags = FALSE;
@@ -346,22 +354,22 @@ main(int argc, char *argv[])
   gchar *savefile = NULL;
   gchar *exclude_args = NULL;
   struct poptOption options[] = {
-    {"tags",	't',  POPT_ARG_NONE|POPT_ARGFLAG_STRIP,   &tags,   0,
-     N_("Output tags (also known as metadata)"), NULL},
-    {"verbose",	'v',  POPT_ARG_NONE|POPT_ARGFLAG_STRIP,   &verbose,   0,
-     N_("Output status information and property notifications"), NULL},
-    {"exclude", 'X',  POPT_ARG_STRING|POPT_ARGFLAG_STRIP, &exclude_args,  0,
-     N_("Do not output status information of TYPE"), N_("TYPE1,TYPE2,...")},
+    {"tags", 't', POPT_ARG_NONE | POPT_ARGFLAG_STRIP, &tags, 0,
+        N_("Output tags (also known as metadata)"), NULL},
+    {"verbose", 'v', POPT_ARG_NONE | POPT_ARGFLAG_STRIP, &verbose, 0,
+        N_("Output status information and property notifications"), NULL},
+    {"exclude", 'X', POPT_ARG_STRING | POPT_ARGFLAG_STRIP, &exclude_args, 0,
+        N_("Do not output status information of TYPE"), N_("TYPE1,TYPE2,...")},
 #ifndef GST_DISABLE_LOADSAVE
-    {"output",	'o',  POPT_ARG_STRING|POPT_ARGFLAG_STRIP, &savefile, 0,
-     N_("Save xml representation of pipeline to FILE and exit"), N_("FILE")},
+    {"output", 'o', POPT_ARG_STRING | POPT_ARGFLAG_STRIP, &savefile, 0,
+        N_("Save xml representation of pipeline to FILE and exit"), N_("FILE")},
 #endif
-    {"no-fault", 'f', POPT_ARG_NONE|POPT_ARGFLAG_STRIP,   &no_fault,   0,
-     N_("Do not install a fault handler"), NULL},
-    {"trace",   'T',  POPT_ARG_NONE|POPT_ARGFLAG_STRIP,   &trace,   0,
-     N_("Print alloc trace (if enabled at compile time)"), NULL},
-    {"iterations",'i',POPT_ARG_INT|POPT_ARGFLAG_STRIP,    &max_iterations,   0,
-     N_("Number of times to iterate pipeline"), NULL},
+    {"no-fault", 'f', POPT_ARG_NONE | POPT_ARGFLAG_STRIP, &no_fault, 0,
+        N_("Do not install a fault handler"), NULL},
+    {"trace", 'T', POPT_ARG_NONE | POPT_ARGFLAG_STRIP, &trace, 0,
+        N_("Print alloc trace (if enabled at compile time)"), NULL},
+    {"iterations", 'i', POPT_ARG_INT | POPT_ARGFLAG_STRIP, &max_iterations, 0,
+        N_("Number of times to iterate pipeline"), NULL},
     POPT_TABLEEND
   };
 
@@ -369,10 +377,10 @@ main(int argc, char *argv[])
   GError *error = NULL;
   gint res = 0;
 
-  free (malloc (8)); /* -lefence */
+  free (malloc (8));            /* -lefence */
 
   bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
-  bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
   gst_alloc_trace_set_flags_all (GST_ALLOC_TRACE_LIVE);
@@ -385,10 +393,11 @@ main(int argc, char *argv[])
     if (*(argv[i]) == '-') {
       if (strlen (argv[i]) == 2) {
         gchar *c = argv[i];
+
         c++;
         if (*c == 'X' || *c == 'o') {
-	  i++;
-	}
+          i++;
+        }
       }
     } else {
       argv[j] = argv[i];
@@ -398,77 +407,82 @@ main(int argc, char *argv[])
   argc = j;
 
   if (!no_fault)
-    fault_setup();
+    fault_setup ();
+
+  sigint_setup ();
+  play_signal_setup ();
 
-  sigint_setup();
-  play_signal_setup();
-  
   if (trace) {
-    if (!gst_alloc_trace_available()) {
+    if (!gst_alloc_trace_available ()) {
       g_warning ("Trace not available (recompile with trace enabled).");
     }
     gst_alloc_trace_print_all ();
   }
 
   /* make a null-terminated version of argv */
-  argvn = g_new0 (char*, argc);
-  memcpy (argvn, argv+1, sizeof (char*) * (argc-1));
+  argvn = g_new0 (char *, argc);
+  memcpy (argvn, argv + 1, sizeof (char *) * (argc - 1));
 #ifndef GST_DISABLE_LOADSAVE
   if (strstr (argv[0], "gst-xmllaunch")) {
-    pipeline = xmllaunch_parse_cmdline ((const gchar**)argvn);
-  } 
-  else 
+    pipeline = xmllaunch_parse_cmdline ((const gchar **) argvn);
+  } else
 #endif
   {
-    pipeline = (GstElement*) gst_parse_launchv ((const gchar**)argvn, &error);
+    pipeline =
+        (GstElement *) gst_parse_launchv ((const gchar **) argvn, &error);
   }
   g_free (argvn);
 
   if (!pipeline) {
     if (error) {
-      fprintf(stderr, _("ERROR: pipeline could not be constructed: %s.\n"),
-              error->message);
+      fprintf (stderr, _("ERROR: pipeline could not be constructed: %s.\n"),
+          error->message);
       g_error_free (error);
     } else {
-      fprintf(stderr, _("ERROR: pipeline could not be constructed.\n"));
+      fprintf (stderr, _("ERROR: pipeline could not be constructed.\n"));
     }
-    exit(1);
+    exit (1);
   } else if (error) {
-    fprintf(stderr, _("WARNING: erroneous pipeline: %s\n"), error->message);
-    fprintf(stderr, _("         Trying to run anyway.\n"));
+    fprintf (stderr, _("WARNING: erroneous pipeline: %s\n"), error->message);
+    fprintf (stderr, _("         Trying to run anyway.\n"));
     g_error_free (error);
   }
-  
+
   if (verbose) {
-    gchar **exclude_list = exclude_args ? g_strsplit (exclude_args, ",", 0) : NULL;
-    g_signal_connect (pipeline, "deep_notify", G_CALLBACK (gst_element_default_deep_notify), exclude_list);
+    gchar **exclude_list =
+        exclude_args ? g_strsplit (exclude_args, ",", 0) : NULL;
+    g_signal_connect (pipeline, "deep_notify",
+        G_CALLBACK (gst_element_default_deep_notify), exclude_list);
   }
   if (tags) {
     g_signal_connect (pipeline, "found-tag", G_CALLBACK (found_tag), NULL);
   }
-  g_signal_connect (pipeline, "error", G_CALLBACK (gst_element_default_error), NULL);
-  
+  g_signal_connect (pipeline, "error", G_CALLBACK (gst_element_default_error),
+      NULL);
+
 #ifndef GST_DISABLE_LOADSAVE
   if (savefile) {
     gst_xml_write_file (GST_ELEMENT (pipeline), fopen (savefile, "w"));
   }
 #endif
-  
+
   if (!savefile) {
-  
+
     if (!GST_IS_BIN (pipeline)) {
       GstElement *real_pipeline = gst_element_factory_make ("pipeline", NULL);
+
       if (real_pipeline == NULL) {
-        fprintf(stderr, _("ERROR: the 'pipeline' element wasn't found.\n"));
-        exit(1);
+        fprintf (stderr, _("ERROR: the 'pipeline' element wasn't found.\n"));
+        exit (1);
       }
       gst_bin_add (GST_BIN (real_pipeline), pipeline);
       pipeline = real_pipeline;
     }
 
-    fprintf(stderr, _("RUNNING pipeline ...\n"));
-    if (gst_element_set_state (pipeline, GST_STATE_PLAYING) == GST_STATE_FAILURE) {
-      fprintf(stderr, _("ERROR: pipeline doesn't want to play.\n"));
+    fprintf (stderr, _("RUNNING pipeline ...\n"));
+    if (gst_element_set_state (pipeline,
+            GST_STATE_PLAYING) == GST_STATE_FAILURE) {
+      fprintf (stderr, _("ERROR: pipeline doesn't want to play.\n"));
       res = -1;
       goto end;
     }
@@ -476,12 +490,12 @@ main(int argc, char *argv[])
     s_clock = gst_bin_get_clock (GST_BIN (pipeline));
 
     if (!GST_FLAG_IS_SET (GST_OBJECT (pipeline), GST_BIN_SELF_SCHEDULABLE)) {
-        g_idle_add (idle_func, pipeline);
-        gst_main ();
+      g_idle_add (idle_func, pipeline);
+      gst_main ();
     } else {
-        g_print ("Waiting for the state change... ");
-        gst_element_wait_state_change (pipeline);
-        g_print ("got the state change.\n");
+      g_print ("Waiting for the state change... ");
+      gst_element_wait_state_change (pipeline);
+      g_print ("got the state change.\n");
     }
 
     gst_element_set_state (pipeline, GST_STATE_NULL);
